package dune-rpc-eio

  1. Overview
  2. Docs

dune-rpc-eio

A client for dune's RPC server for programs written against Eio.

With a dune server running in watch mode, a program can build a path or an alias, run the tests, read the diagnostics of the last build and promote a corrected file.

Install

opam install dune-rpc-eio

Test

dune runtest

The tests run against a stub dune server over a socket pair, and against a temporary build directory they make themselves.

License

ISC. See LICENSE.md.