Legend:
Page
Library
Module
Module type
Parameter
Class
Class type
Page
Library
Module
Module type
Parameter
Class
Class type
A client for dune's RPC server for programs written against Eio.
With a dune server running in watch mode, a program can build a path or an alias, run the tests, read the diagnostics of the last build and promote a corrected file.
opam install dune-rpc-eiodune runtestThe tests run against a stub dune server over a socket pair, and against a temporary build directory they make themselves.
ISC. See LICENSE.md.